@@ -70,3 +70,15 @@ class ConfigControl(Config):
         default=False,
         help_string="Should we daemonize?",
     )
+    check_root = ParamCreator.create_bool(
+        default=False,
+        help_string="Should we check that we are running as root?",
+    )
+    check_tools = ParamCreator.create_bool(
+        default=False,
+        help_string="Should we check that we have the right tools?",
+    )
+    configure_proxy = ParamCreator.create_bool(
+        default=True,
+        help_string="Should we configure the proxy?",
+    )
